package com.kmall.schedule.dao;

import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @author huangyq
 * @date 2019/6/10.
 */
@Component
public interface QzStoreCampMinusMapper {

    /**
     * 查询进行中且超时的满减满折数据
     *
     * @return
     */
    List<Map> queryCampMinusListByPasting();

    /**
     * 查询状态为未开始，且开始时间已小于或等于当前时间的满减满折活动数据
     * @return
     */
    List<Map> queryCampMinusListByPastNotStart();
    /**
     * 更新过期状态
     *
     * @param fromObject
     */
    void updateStoreCampMinus(Map fromObject);

    Map selectAdIdByTopicId(@Param("storeTopicId") Integer storeTopicId);

    /**
     * 将失效优惠券广告位设置为失效
     * @param fromObject
     */
    void updateAd(Map fromObject);

    void updateStoreTopic(@Param("storeTopicId") Integer storeTopicId);
}
